==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/activity/impl/FlowFinalNodeSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.activity.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.activity.ControlNodeSet;
import io.ciera.tool.sql.ooaofooa.activity.FlowFinalNode;
import io.ciera.tool.sql.ooaofooa.activity.FlowFinalNodeSet;
import io.ciera.tool.sql.ooaofooa.activity.impl.ControlNodeSetImpl;

import java.util.Arrays;
import java.util.List;


public class FlowFinalNodeSetImpl extends InstanceSet<FlowFinalNodeSet,FlowFinalNode> implements FlowFinalNodeSet {

    // attributes
    @Override
    public void setDescrip( String m_Descrip ) throws XtumlException {
        for ( FlowFinalNode flowfinalnode : this ) flowfinalnode.setDescrip( m_Descrip );
    }
    @Override
    public void setId( UniqueId ref_Id ) throws XtumlException {
        for ( FlowFinalNode flowfinalnode : this ) flowfinalnode.setId( ref_Id );
    }


    // selections
    @Override
    public ControlNodeSet R1106_is_a_ControlNode() throws XtumlException {
        ControlNodeSet controlnodeset = new ControlNodeSetImpl();
        for ( FlowFinalNode flowfinalnode : this ) controlnodeset.add( flowfinalnode.R1106_is_a_ControlNode() );
        return controlnodeset;
    }


    @Override
    public FlowFinalNode nullElement() {
        return FlowFinalNodeImpl.EMPTY_FLOWFINALNODE;
    }

    @Override
    public FlowFinalNodeSet emptySet() {
      return new FlowFinalNodeSetImpl();
    }

    @Override
    public FlowFinalNodeSet value() {
        return this;
    }

    @Override
    public List<FlowFinalNode> elements() {
        return Arrays.asList(toArray(new FlowFinalNode[0]));
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/ooaofooa/activity/impl/FlowFinalNodeSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.activity.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.activity.ControlNodeSet;
import io.ciera.tool.sql.ooaofooa.activity.FlowFinalNode;
import io.ciera.tool.sql.ooaofooa.activity.FlowFinalNodeSet;
import io.ciera.tool.sql.ooaofooa.activity.impl.ControlNodeSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class FlowFinalNodeSetImpl extends InstanceSet<FlowFinalNodeSet,FlowFinalNode> implements FlowFinalNodeSet {

    public FlowFinalNodeSetImpl() {
    }

    public FlowFinalNodeSetImpl(Comparator<? super FlowFinalNode> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setDescrip( String m_Descrip ) throws XtumlException {
        for ( FlowFinalNode flowfinalnode : this ) flowfinalnode.setDescrip( m_Descrip );
    }
    @Override
    public void setId( UniqueId ref_Id ) throws XtumlException {
        for ( FlowFinalNode flowfinalnode : this ) flowfinalnode.setId( ref_Id );
    }


    // selections
    @Override
    public ControlNodeSet R1106_is_a_ControlNode() throws XtumlException {
        ControlNodeSet controlnodeset = new ControlNodeSetImpl();
        for ( FlowFinalNode flowfinalnode : this ) controlnodeset.add( flowfinalnode.R1106_is_a_ControlNode() );
        return controlnodeset;
    }


    @Override
    public FlowFinalNode nullElement() {
        return FlowFinalNodeImpl.EMPTY_FLOWFINALNODE;
    }

    @Override
    public FlowFinalNodeSet emptySet() {
      return new FlowFinalNodeSetImpl();
    }

    @Override
    public FlowFinalNodeSet emptySet(Comparator<? super FlowFinalNode> comp) {
      return new FlowFinalNodeSetImpl(comp);
    }

    @Override
    public FlowFinalNodeSet value() {
        return this;
    }

    @Override
    public List<FlowFinalNode> elements() {
        return Arrays.asList(toArray(new FlowFinalNode[0]));
    }

}
